#
# spec file for package just
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           just
Version:        1.23.0
Release:        1.2
Summary:        Commmand runner
License:        (Apache-2.0 OR MIT) AND Unicode-DFS-2016 AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (MIT OR Unlicense) AND Apache-2.0 AND BSD-3-Clause AND CC0-1.0 AND MIT AND CC0-1.0
Group:          Development/Tools/Building
URL:            https://github.com/casey/just
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  rust+cargo
BuildRequires:  zstd

%description
Just is a command runner. Although it shares
some similarities with "make", it is not a build
system.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash command-line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description fish-completion
Fish command-line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup -a1

%build
%{cargo_build} --all-features

%install
%{cargo_install} --all-features
install -Dm644 -T completions/just.bash %{buildroot}%{_datadir}/bash-completion/completions/just
install -Dm644 -T completions/just.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/just.fish
install -Dm644 -T completions/just.zsh %{buildroot}%{_datadir}/zsh/site-functions/_just

%files
%license LICENSE
%doc *.md
%{_bindir}/just

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%changelog
* Thu Jan 18 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.23.0:
  * Allow setting custom confirm prompt
  * Add `set quiet` and `[no-quiet]`
  * Add `just_pid` function
  * Include completion scripts in releases
  * Run imports in working directory of importer
  * Tweak readme table formatting
  * Add functions to return XDG base directories
  * Don't abbreviate just in README
  * Add `--no-deps` to skip running recipe dependencies
  * Ignore [private] recipes in just --list
  * Add a dash to tempdir prefix
  * Don't conflate recipes with the same name in different modules
  * Clarify that UUID is version 4
  * Make sigil stripping from recipe lines less incomprehensible
  * Refactor invalid path argument check
  * Recipes can be invoked with path syntax
  * Move table of contents pointer to right
  * Add `--format` and `--initialize` as aliases for `--fmt` and `--init`
  * Use box-drawing characters in error messages
  * Optional modules and imports
  * Use Self
  * Print submodule recipes in --summary
  * Expand tilde in import and module paths
  * Document import override behavior
  * Override imported recipes
  * Document submodule working directory
  * Run recipes with working directory set to submodule directory
  * Allow mod statements with path to source file
* Thu Dec 28 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.19.0:
  * Add modules
* Mon Dec 25 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.18.1:
  * Display a descriptive error for `!include` directives
  * Tweak readme
  * Stabilize `!include path` as `import 'path'`
* Wed Dec 20 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.17.0:
  * Pass justfile path to default chooser
  * Pass `--unstable` and `--color always` to default chooser
  * Update Gentoo package repository
  * Fix readme header level
  * Document line continuations
  * List included recipes in load order
  * Rename Justfile::first → Justfile::default
  * Don't default to included recipes
* Sat Dec  2 2023 xtexchooser@duck.com
- Update to version 1.16.0:
  * Fix readme typo
  * Fix Fish completion script
  * Add ARMv6 release target
  * Add `semver_matches` function
  * Clean up error display
  * Misc fixes
  * Fix readme build badge
  * Add `dotenv-filename` and `dotenv-path` settings
  * Fix set tempdir grammar
  * Add version to attributes
  * Allow setting echoed recipe line color
  * Update README.md
* Wed Oct 25 2023 Soc Virnyl Estela <contact@uncomfyhalomacro.pl>
- Update to version 1.15.0:
  * Add Nushell completion script
  * Update Indentation Documentation
  * Allow unstable features to be enabled with environment variable
  * Fix triple-quoted string example in readme
  * README fix: the -d in `mktemp -d` is required to created folders.
  * Placate clippy
  * Add num_cpus() function
  * Document Windows Package Manager install instructions
  * Test unpaired escaped carriage return error
  * Allow escaping newlines
  * Stabilize JSON dump format
  * Avoid grep aliases in bash completions
  * Clarify [unix] attribute in readme
  * Add env() function
  * Add descriptions to fish recipe completions
  * Allow selecting multiple recipes with default chooser
  * Add better documentation for --dump and --fmt
* Sat Sep  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Revert update of vendored dependencies.
* Sat Sep  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies
- Update source cargo_config
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sat Jun  3 2023 socvirnyl.estela@gmail.com
- Update to version 1.14.0:
  * Ignore clippy::let_underscore_untyped
  * Use `just --show` in default chooser
  * Update README to reflect new attribute syntax
  * Allow multiple attributes on one line
  * Analyze and Compiler tweaks
  * Downgrade to TLS 1.2 in install script
* Sun Mar  5 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for just 1.13.0
